@@ -35,6 +35,16 @@ class SensorImpactFDD:
                f'config.json', quiet=False, fuzzy=True)
             print('config.json file is downloaded and added to the working path.')
 
+            print('Downloading sensor fault probability table...')
+            gdown.download("https://drive.google.com/file/d/1UwwjCYkKuouR6ZfxggeNlmlKmrCGFgCI/view?usp=sharing",
+               f'sensor_fault_probability_table.csv', quiet=False, fuzzy=True)
+            print('sensor_fault_probability_table.csv is downloaded and added to the working path.')
+
+            print('Downloading sensor group information...')
+            gdown.download("https://drive.google.com/file/d/1cS-l1-zKH4uZJcLbVg9vxaXJFSe9lwhx/view?usp=sharing",
+               f'Suggested Sensor Sets.csv', quiet=False, fuzzy=True)
+            print('Suggested Sensor Sets.csv is downloaded and added to the working path.')
+
         with open("config.json", "r") as jsonfile:
             self.config = json.load(jsonfile)
 
@@ -252,13 +262,13 @@ class SensorImpactFDD:
             inputs = faulty_and_unfaulty_inputs_output.iloc[:, 0:-1]
             output = faulty_and_unfaulty_inputs_output['label']
 
-            if feature_selection_config['filter'][0] == True:
+            if feature_selection_config['filter'][0] != False:
                 pass
 
-            elif feature_selection_config['wrapper'] == True:
+            if feature_selection_config['wrapper'] != False:
                 pass
 
-            elif feature_selection_config['embedded'] == True:
+            if feature_selection_config['embedded'] == True:
                 # model with defined sensors
                 # split training and testing
                 cv = KFold(n_splits=4, shuffle=True, random_state=42)
@@ -293,9 +303,9 @@ class SensorImpactFDD:
                 feature_importance_temp.to_csv(
                     f'{sensor_selection_analysis_result_folder_dir}/important_sensor_all_faults.csv', index=None)
                 print('Selection Analysis Results (all faults and not by fault type) Saved!')
-
-            else:
-                raise Exception(f"The feature selection method is unknown.")
+            #
+            # else:
+            #     raise Exception(f"The feature selection method is unknown.")
 
         elif by_fault_type == True:
 
@@ -310,13 +320,13 @@ class SensorImpactFDD:
                 inputs = faulty_and_unfaulty_inputs_output.iloc[:, 0:-1]
                 output = faulty_and_unfaulty_inputs_output['label']
 
-                if feature_selection_config['filter'][0] == True:
+                if feature_selection_config['filter'][0] != False:
                     pass
 
-                elif feature_selection_config['wrapper'] == True:
+                if feature_selection_config['wrapper'] != False:
                     pass
 
-                elif feature_selection_config['embedded'] == True:
+                if feature_selection_config['embedded'] == True:
                     # model with defined sensors
                     cv = KFold(n_splits=4, shuffle=True, random_state=42)
                     for train_index, test_index in cv.split(inputs):
@@ -349,9 +359,9 @@ class SensorImpactFDD:
                         by=['importance'], ascending=False).sensor_name.tolist()
                     feature_importance_temp = feature_importance_temp[0:top_n_features]
                     feature_importance_summary_list[fault_type] = feature_importance_temp
-
-                else:
-                    raise Exception(f"The feature selection method is unknown.")
+            #
+            # else:
+            #     raise Exception(f"The feature selection method is unknown.")
 
             feature_importance_summary_list.to_csv(
                 f'{sensor_selection_analysis_result_folder_dir}/important_sensor_by_fault_type.csv', index=None)
